==> Pyrogram-0.6.5-py3-none-any.whl: pyrogram/api/functions/contacts/import_contacts.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class ImportContacts(Object):
    """
    Attributes:
        ID (:obj:`int`): ``0x2c800be5``

    Args:
        contacts: List of :class:`pyrogram.api.types.InputContact`

    Returns:
        :class:`pyrogram.api.types.contacts.ImportedContacts`

    Raises:
        :class:`pyrogram.Error`
    """
    ID = 0x2c800be5

    def __init__(self, contacts):
        self.contacts = contacts  # Vector<InputContact>

    @staticmethod
    def read(b: BytesIO, *args) -> "ImportContacts":
        # No flags
        
        contacts = Object.read(b)
        
        return ImportContacts(contacts)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Vector(self.contacts))
        
        return b.getvalue()

==> Pyrogram-0.7.1-py3-none-any.whl: pyrogram/api/functions/contacts/import_contacts.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class ImportContacts(Object):
    """Attributes:
        ID: ``0x2c800be5``

    Args:
        contacts: List of :obj:`InputPhoneContact <pyrogram.api.types.InputPhoneContact>`

    Raises:
        :obj:`Error <pyrogram.Error>`

    Returns:
        :obj:`contacts.ImportedContacts <pyrogram.api.types.contacts.ImportedContacts>`
    """
    ID = 0x2c800be5

    def __init__(self, contacts):
        self.contacts = contacts  # Vector<InputContact>

    @staticmethod
    def read(b: BytesIO, *args) -> "ImportContacts":
        # No flags
        
        contacts = Object.read(b)
        
        return ImportContacts(contacts)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Vector(self.contacts))
        
        return b.getvalue()
